@@ -268,6 +268,12 @@ class Bits32DummyBarComp( Component ):
     def upblk():
       s.out @= s.in_ + Bits32(42)
 
+class TestCompExplicitModuleName( Component ):
+  def construct( s ):
+    s.in_ = InPort( 32 )
+    from pymtl3.passes.backends.verilog import VerilogTranslationPass
+    s.set_metadata( VerilogTranslationPass.explicit_module_name, "NewChildDUTName" )
+
 #-------------------------------------------------------------------------
 # Test Components
 #-------------------------------------------------------------------------
@@ -1255,6 +1261,19 @@ class CaseHeteroCompArrayComp:
       [   -1,     42,    -1,    84],
   ]
 
+class CaseChildExplicitModuleName:
+  class DUT( Component ):
+    def construct( s ):
+      s.in_ = InPort( 32 )
+      s.child = TestCompExplicitModuleName()
+      s.child.in_ //= s.in_
+  TV_IN  = _set( 'in_', Bits32, 0 )
+  TV_OUT = _check()
+  TV =\
+  [
+      [ 0 ],
+  ]
+
 #-------------------------------------------------------------------------
 # Test cases without errors
 #-------------------------------------------------------------------------
